// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_WEBUI_ASH_MAKO_URL_CONSTANTS_H_
#define CHROME_BROWSER_UI_WEBUI_ASH_MAKO_URL_CONSTANTS_H_

namespace ash {

extern const char kChromeUIMakoHost[];
extern const char kChromeUIMakoURL[];
extern const char kChromeUIMakoOrcaURL[];
extern const char kChromeUIMakoPrivacyURL[];
extern const char kChromeUILobsterURL[];

extern const char kOrcaModeParamKey[];
extern const char kOrcaWriteMode[];
extern const char kOrcaRewriteMode[];

extern const char kOrcaPresetParamKey[];
extern const char kOrcaFreeformParamKey[];

extern const char kOrcaFeedbackEnabledParamKey[];

extern const char kOrcaResizingEnabledParamKey[];

extern const char kOrcaHostLanguageParamKey[];

extern const char kOrcaMagicBoostParamKey[];

extern const char kLobsterPromptParamKey[];

extern const char kLobsterModeParamKey[];

extern const char kLobsterDownloadModeValue[];

extern const char kLobsterInsertModeValue[];

extern const char kLobsterFeedbackEnabledParamKey[];

}  // namespace ash

#endif  // CHROME_BROWSER_UI_WEBUI_ASH_MAKO_URL_CONSTANTS_H_
